@@ -22,19 +22,19 @@ void KAccountsDeclarativePlugin::registerTypes(const char *uri)
 {
     // Version 1.0
     // Consider this registration deprecated - use the one named ...Job below instead
-    qmlRegisterType<CreateAccountJob>(uri, 1, 0, "CreateAccount");
+    qmlRegisterType<KAccounts::CreateAccountJob>(uri, 1, 0, "CreateAccount");
 
     // Version 1.1
     // Consider this registration deprecated - use the one named ...Job below instead
-    qmlRegisterType<AccountServiceToggleJob>(uri, 1, 1, "AccountServiceToggle");
+    qmlRegisterType<KAccounts::AccountServiceToggleJob>(uri, 1, 1, "AccountServiceToggle");
 
     // Version 1.2
-    qmlRegisterType<AccountsModel>(uri, 1, 2, "AccountsModel");
-    qmlRegisterType<ProvidersModel>(uri, 1, 2, "ProvidersModel");
-    qmlRegisterType<ServicesModel>(uri, 1, 2, "ServicesModel");
+    qmlRegisterType<KAccounts::AccountsModel>(uri, 1, 2, "AccountsModel");
+    qmlRegisterType<KAccounts::ProvidersModel>(uri, 1, 2, "ProvidersModel");
+    qmlRegisterType<KAccounts::ServicesModel>(uri, 1, 2, "ServicesModel");
 
-    qmlRegisterType<AccountServiceToggleJob>(uri, 1, 2, "AccountServiceToggleJob");
-    qmlRegisterType<ChangeAccountDisplayNameJob>(uri, 1, 2, "ChangeAccountDisplayNameJob");
-    qmlRegisterType<CreateAccountJob>(uri, 1, 2, "CreateAccountJob");
-    qmlRegisterType<RemoveAccountJob>(uri, 1, 2, "RemoveAccountJob");
+    qmlRegisterType<KAccounts::AccountServiceToggleJob>(uri, 1, 2, "AccountServiceToggleJob");
+    qmlRegisterType<KAccounts::ChangeAccountDisplayNameJob>(uri, 1, 2, "ChangeAccountDisplayNameJob");
+    qmlRegisterType<KAccounts::CreateAccountJob>(uri, 1, 2, "CreateAccountJob");
+    qmlRegisterType<KAccounts::RemoveAccountJob>(uri, 1, 2, "RemoveAccountJob");
 }
