@@ -13,6 +13,9 @@
 
 #include <QStringList>
 
+namespace KAccounts
+{
+
 /**
  * @brief A job used to change the enabled state of a specific service on a specific account
  */
@@ -23,17 +26,17 @@ class KACCOUNTS_EXPORT AccountServiceToggleJob : public KJob
     Q_PROPERTY(QString serviceId READ serviceId WRITE setServiceId NOTIFY serviceIdChanged)
     Q_PROPERTY(bool serviceEnabled READ serviceEnabled WRITE setServiceEnabled NOTIFY serviceEnabledChanged)
 public:
-    explicit AccountServiceToggleJob(QObject* parent = nullptr);
-    virtual ~AccountServiceToggleJob();
+    explicit AccountServiceToggleJob(QObject *parent = nullptr);
+    ~AccountServiceToggleJob() override;
 
     void start() override;
 
     QString accountId() const;
-    void setAccountId(const QString& accountId);
+    void setAccountId(const QString &accountId);
     Q_SIGNAL void accountIdChanged();
 
     QString serviceId() const;
-    void setServiceId(const QString& serviceId);
+    void setServiceId(const QString &serviceId);
     Q_SIGNAL void serviceIdChanged();
 
     bool serviceEnabled() const;
@@ -41,8 +44,12 @@ public:
 
 Q_SIGNALS:
     void serviceEnabledChanged();
+
 private:
     class Private;
-    Private* d;
+    Private *d;
 };
-#endif//ACCOUNTSERVICETOGGLE_H
+
+};
+
+#endif // ACCOUNTSERVICETOGGLE_H
