@@ -13,6 +13,9 @@
 
 #include <QString>
 
+namespace KAccounts
+{
+
 /**
  * @brief A job which will attempt to remove the specified account
  */
@@ -22,7 +25,7 @@ class KACCOUNTS_EXPORT RemoveAccountJob : public KJob
     Q_PROPERTY(QString accountId READ accountId WRITE setAccountId NOTIFY accountIdChanged)
 public:
     explicit RemoveAccountJob(QObject *parent = nullptr);
-    virtual ~RemoveAccountJob();
+    ~RemoveAccountJob() override;
 
     void start() override;
 
@@ -34,4 +37,7 @@ private:
     class Private;
     Private *d;
 };
+
+};
+
 #endif // REMOVEACCOUNT_H
